@@ -4,12 +4,15 @@ import yaml
 from pathlib import Path
 from t2wml.spreadsheets.sheet import SpreadsheetFile
 from t2wml.parsing.cleaning_functions import *
+from t2wml.mapping.datamart_edges import clean_id
 from t2wml.input_processing.clean_yaml_parsing import get_cleaned_dataframe
 from t2wml.settings import t2wml_settings
 
 t2wml_settings.cache_data_files_folder=None
 
 class TestScripts(unittest.TestCase):
+    def test_Clean_id(self):
+        assert clean_id("My very happy LOVELY... yoga class? לחדגילדחג") == "my_very_happy_lovely_yoga_class"
     def test_ftfy(self):
         assert ftfy("schÃ¶n")=="schön"
 
